Name:           sndio
Version:        1.10.0
Release:        1%{?dist}
Summary:        Portable audio & MIDI framework from OpenBSD
License:        ISC
URL:            https://sndio.org/
Source0:        https://sndio.org/sndio-%{version}.tar.gz

# -- build-time deps
BuildRequires: pkgconfig
BuildRequires: gcc
BuildRequires: make
BuildRequires: alsa-lib-devel
# if you want OSS4 support:
BuildRequires: libbsd-devel
BuildRequires: systemd-rpm-macros

# -- runtime deps pulled in by subpackages

%description
 Sndio is a small audio and MIDI framework part of the OpenBSD project and ported to FreeBSD, Linux and NetBSD. It provides a lightweight audio & MIDI server and a fully documented user-space API to access either the server or the hardware directly in a uniform way. Sndio is designed to work for desktop applications, but pays special attention to synchronization mechanisms and reliability required by music applications. Reliability through simplicity are part of the project goals.

%prep
%autosetup -n sndio-%{version}

%build
./configure \
  --prefix=%{_prefix} \
  --exec-prefix=%{_exec_prefix} \
  --bindir=%{_bindir} \
  --datadir=%{_datadir} \
  --includedir=%{_includedir} \
  --libdir=%{_libdir} \
  --mandir=%{_mandir}
make %{?_smp_mflags}

%check
:   # no upstream test suite

%install
make install DESTDIR=%{buildroot}

# runtime socket dir
install -d -m0755 %{buildroot}%{_localstatedir}/run/sndiod

# systemd unit
install -D -m0644 contrib/sndiod.service \
    %{buildroot}%{_unitdir}/sndiod.service
install -D -m0644 contrib/default.sndiod \
    %{buildroot}%{_sysconfdir}/default/sndiod

%changelog
* Thu May 15 2025 Tim Wendt <techtasie@gmail.com> - 1.10.0-1
- initial build

#-------------------------------------------------
# libs: provides libsndio.so.* for runtime
%package libs
Summary: Runtime libraries for sndio

%description libs
Runtime libraries for the sndio audio & MIDI framework.

%files libs
%license LICENSE
%{_libdir}/libsndio.so.*

# section 7 overview page
%{_mandir}/man7/sndio.7*

#-------------------------------------------------
# devel: headers & .so symlink
%package devel
Summary: Development files for sndio
Requires: %{name}-libs = %{version}-%{release}

%description devel
Headers and development libraries for the sndio audio & MIDI framework.

%files devel
%{_includedir}/sndio.h
%{_libdir}/libsndio.so

# pkgconfig
%{_libdir}/pkgconfig/sndio.pc

# section 3 API man-pages
%{_mandir}/man3/*.3*

#-------------------------------------------------
# tools: au* utilities
%package tools
Summary: Command-line tools for sndio
Requires: %{name}-libs = %{version}-%{release}
Recommends: sndiod

%description tools
Basic command-line tools for use with a local or remote sndio server,
including the ‘aucat’ playback client.

%files tools
%{_bindir}/aucat
%{_bindir}/midicat
%{_bindir}/sndioctl

# section 1 manpages for those tools
%{_mandir}/man1/aucat.1*
%{_mandir}/man1/midicat.1*
%{_mandir}/man1/sndioctl.1*

#-------------------------------------------------
# daemon: sndiod server
%package sndiod
Summary: sndio sound server
Requires: %{name}-libs = %{version}-%{release}
Recommends: %{name}-tools

%description sndiod
The sndiod sound server daemon for the sndio framework.

%files sndiod
%{_bindir}/sndiod
%dir %{_localstatedir}/run/sndiod
%{_unitdir}/sndiod.service
%config(noreplace) %{_sysconfdir}/default/sndiod
%{_mandir}/man8/sndiod.8*

%post sndiod
%systemd_post sndiod.service

%preun sndiod
%systemd_preun sndiod.service

%postun sndiod
%systemd_postun sndiod.service
